@@ -18,18 +18,14 @@ pub fn establish_connection() -> PgConnection {
 fn diesel_test() -> Result<(), Box<dyn std::error::Error>> {
     use lrau::schema::login_users;
     use lrau::schema::login_users::dsl as users_dsl;
-    use lrau::diesel_support::SqlUser;
+    use lrau::sql_support::SqlUser;
 
     // Get the permissions
     let permissions: lrau::Permissions =
         toml::from_str(include_str!("./generic.toml")).unwrap();
 
     // Create a user.
-    let user = lrau::User::new(
-        String::from("john_t"),
-        String::from("1234"),
-        permissions,
-    );
+    let user = lrau::User::new(String::from("john_t"), "1234", permissions)?;
 
     // Get a raw user.
     let raw_user = SqlUser::from(user.clone());
